@@ -1,18 +1,15 @@
 """Seafile api client"""
-from seafileapi.exceptions import ClientHttpError, OperationError, DoesNotExist
-from seafileapi.repo import RepoRevision
-
 from seafileapi_extended.admin import SeafileAdmin
 from seafileapi_extended.client import SeafileApiClient
-from seafileapi_extended.exceptions import UserExisted, GroupExisted
+from seafileapi_extended.exceptions import UserExisted, GroupExisted, ClientHttpError, OperationError, DoesNotExist
 from seafileapi_extended.group import Group, AdminGroup, GroupMember
 from seafileapi_extended.groups import Groups, AdminGroups
 from seafileapi_extended.files import SeafDir, SeafFile
-from seafileapi_extended.repo import Repo
+from seafileapi_extended.repo import Repo, RepoRevision
 from seafileapi_extended.repos import Repos
 from seafileapi_extended.utils import is_ascii
 
-__version__ = "1.0.1"
+__version__ = "1.0.2"
 
 
 __all__ = [
